Crate rust_sitter_tool
source ·Functions
Using the
cc crate, generates and compiles a C parser with Tree Sitter
for every Rust Sitter grammar found in the given module and recursive
submodules.Generates JSON strings defining Tree Sitter grammars for every Rust Sitter
grammar found in the given module and recursive submodules.